@@ -4,7 +4,7 @@
 #' @description Check that the provided LifeHistData is in the correct format.
 #'
 #' @param LifeHistData the dataframe with ID - Sex - Birth year, and optionally
-#'   BY.min - BY.max.
+#'   BY.min - BY.max - YearLast.
 #' @param gID  character vector with names of genotyped individuals, i.e.
 #'   rownames(GenoM).
 #' @param sorted  logical, return lifehistdata for genotyped individuals only,
@@ -25,11 +25,12 @@ CheckLH <- function(LifeHistData, gID = NA, sorted=TRUE, returnDups = FALSE)
   if (is.null(gID))  gID <- NA
   if (is.null(LifeHistData)) {
     LH.OUT <- data.frame(ID = gID,
-                       Sex = 3,
-                       BirthYear = -999,
-                       BY.min = -999,
-                       BY.max = -999,
-                       stringsAsFactors = FALSE)
+                         Sex = 3,
+                         BirthYear = -999,
+                         BY.min = -999,
+                         BY.max = -999,
+                         Year.last = -999,
+                         stringsAsFactors = FALSE)
     if (returnDups) {
       return( list(DupLifeHistID = NULL, NoLH = NULL, LifeHistData = LH.OUT) )
     } else {
@@ -40,98 +41,104 @@ CheckLH <- function(LifeHistData, gID = NA, sorted=TRUE, returnDups = FALSE)
     stop("invalid value for LifeHistData, provide NULL or dataframe",
          call.=FALSE)
 
-  # check if LH ID's match genotype data
-  names(LifeHistData)[1:3] <- c("ID", "Sex", "BirthYear")
+  if (ncol(LifeHistData) < 3)
+    stop("LifeHistData must have at least 3 columns: ID - Sex - BirthYear")
+
+
+  # check IDs (column 1) ---
+  colnames(LifeHistData)[1] <- 'ID'
   LifeHistData$ID <- as.character(LifeHistData$ID)
+  if (any(grepl(" ", LifeHistData$ID))) {
+    stop("LifeHistData IDs (column 1) must not include spaces", call.=FALSE)
+  }
   if (!all(is.na(gID))) {
     gID <- as.character(gID)
     if (length(intersect(LifeHistData$ID, gID))==0)
-      stop("None of the genotyped individuals included in lifehistory data",
+      stop("None of the IDs in LifeHistData column 1 match the rownames of GenoM",
            call.=FALSE)
   } else {
     if (sorted)  stop("if sorted=TRUE, gID cannot be NA", call.=FALSE)
   }
 
 
-  # check/add BY.min & BY.max columns ----
-  if (ncol(LifeHistData)==3) {
-    LifeHistData$BY.min <- NA
-    LifeHistData$BY.max <- NA
-  } else if (any(colnames(LifeHistData) %in% c("BY.min", "BY.max"))) {
-    if (colnames(LifeHistData)[4] == "BY.min" & colnames(LifeHistData)[5] == "BY.max") {
-      LifeHistData <- LifeHistData[, 1:5]
-    } else {
-      if (any(colnames(LifeHistData) == "BY.min")) {
-        BYmin <- LifeHistData$BY.min
-      } else {
-        BYmin <- NA
-      }
-      if (any(colnames(LifeHistData) == "BY.min")) {
-        BYmax <- LifeHistData$BY.max
-      } else {
-        BYmax <- NA
-      }
-      LifeHistData <- LifeHistData[, 1:3]
-      LifeHistData$BY.min <- BYmin
-      LifeHistData$BY.max <- BYmax
+  # Flexible column order and capitalisation ---
+
+  which_else <- function(x, z) ifelse(any(x), which(x), z)   # z = default column if name not found
+
+  LH_colnames <- tolower(colnames(LifeHistData))
+  colnum <- c('Sex' = which_else(grepl('sex', LH_colnames), 2),
+              'BirthYear' = which_else((grepl('birthyear', LH_colnames) | grepl('by', LH_colnames)) &
+                                         !grepl('min', LH_colnames) & !grepl('max', LH_colnames), 3),
+              'BY.min' = which_else((grepl('birthyear', LH_colnames) | grepl('by', LH_colnames)) &
+                                      grepl('min', LH_colnames), 4),
+              'BY.max' = which_else((grepl('birthyear', LH_colnames) | grepl('by', LH_colnames)) &
+                                      grepl('max', LH_colnames), 5),
+              'Year.last' = which_else(grepl('last', LH_colnames), 6) )
+  if (any(duplicated(colnum))) {
+    stop("Confused about LifeHistData column order; Please provide data as ",
+         "ID - Sex - BirthYear - BY.min - BY.max - Year.last", call.=FALSE)
+  }
+
+  # optional columns
+  for (x in c('BY.min', 'BY.max', 'Year.last')) {
+    if (colnum[x] > ncol(LifeHistData)) {
+      LifeHistData[, x] <- -999
     }
-  } else if (ncol(LifeHistData)==5) {
-    LifeHistData <- LifeHistData[, 1:5]
-    names(LifeHistData)[4:5] <- c("BY.min", "BY.max")
-  } else {
-    stop("Confused by columns in LifeHistData", call.=FALSE)
   }
+
+
+  # column renaming & order ---
+  for (x in seq_along(colnum)) {
+    colnames(LifeHistData)[ colnum[x] ] <- names(colnum)[x]
+  }
+  LifeHistData <- LifeHistData[, c('ID', 'Sex', 'BirthYear', 'BY.min', 'BY.max', 'Year.last')]
+
+
+  # check Sex ----
+  if (!all(LifeHistData$Sex %in% c(1,2,3,4,NA))) {
+    sex_msg <- "LifeHistData column 'Sex' should be coded as 1=female, 2=male, 3/<NA>=unknown, 4=hermaphrodite"
+    if (sum(LifeHistData$Sex %in% 1:4) < nrow(LifeHistData)/10) {   # <10% valid non-missing coding
+      stop(sex_msg, call.=FALSE)
+    } else {
+      warning(sex_msg, "\n These values are converted to <NA>/3: ", setdiff(LifeHistData$Sex, 1:4),
+              call.=FALSE, immediate=TRUE)
+      LifeHistData$Sex[!LifeHistData$Sex %in% c(1:4)] <- 3
+    }
+  }
+
+
+  # check birth years ----
+  LifeHistData$BY.max[which(LifeHistData$BY.max < 0)] <- NA
   if (any(LifeHistData$BY.max < LifeHistData$BY.min, na.rm=TRUE)) {
-    stop("'BY.max' must be greater than or equal to 'BY.min', or NA", call.=FALSE)
+    stop("'BY.max' must be greater than or equal to 'BY.min', or <NA>/-999", call.=FALSE)
   }
 
-
-  # check if column entries are valid ----
-  if (any(grepl(" ", LifeHistData$ID))) {
-    stop("LifeHistData IDs must not include spaces", call.=FALSE)
-  }
-  for (x in c("Sex", "BirthYear", "BY.min", "BY.max")) {
+  for (x in c("BirthYear", "BY.min", "BY.max", 'Year.last')) {
     IsInt <- check.integer(LifeHistData[,x])
     if (any(!IsInt, na.rm=TRUE)) {
-#      if (sum(!IsInt, na.rm=TRUE) > sum(!is.na(LifeHistData[,x]))/2) {
-        stop("LifeHistData column ", x, " should be integers (whole numbers)",
-             call.=FALSE)
-#      } else {
-#        warning("Converting all values in LifeHistData column ", x, " to integers",
-#                immediate. = TRUE)
-#      }
+      warning("In LifeHistData column ", x, ", these values are converted to <NA>/-999: ",
+              unique(LifeHistData[,x][IsInt %in% FALSE]), immediate.=TRUE, call.=FALSE)
     }
     LifeHistData[, x] <- ifelse(IsInt, suppressWarnings(as.integer(as.character(LifeHistData[, x]))), NA)
-    if (x=="Sex") {
-      if ((sum(LifeHistData$Sex %in% c(1,2,4)) < nrow(LifeHistData)/10) &
-          (sum(is.na(LifeHistData$Sex)) + sum(LifeHistData$Sex==3, na.rm=TRUE) < nrow(LifeHistData)/2)) {
-        stop("LifeHistData column 2 should contain Sex coded as 1=female, 2=male, 3/NA=unknown, 4=hermaphrodite",
-             call.=FALSE)
-      }
-      LifeHistData$Sex[is.na(LifeHistData$Sex)] <- 3
-      LifeHistData$Sex[!LifeHistData$Sex %in% 1:4] <- 3
-    } else {
-      LifeHistData[is.na(LifeHistData[,x]), x] <- -999
-      LifeHistData[LifeHistData[,x] < 0, x] <- -999
-    }
+    LifeHistData[is.na(LifeHistData[,x]), x] <- -999
+    LifeHistData[LifeHistData[,x] < 0, x] <- -999
   }
 
+
   # duplicate check ----
   LifeHistData <- unique(LifeHistData)    # doesn't matter if both entries are identical
   OUT <- list(DupLifeHistID = NULL, NoLH = NULL)
   if (any(duplicated(LifeHistData$ID))) {
     if (returnDups) {
-      r1 <- which(duplicated(LifeHistData$ID))
-      r2 <- which(duplicated(LifeHistData$ID, fromLast=TRUE))
-      OUT$DupLifeHistID <- with(LifeHistData,
-                                data.frame(row1 = r1,
-                                           row2 = r2,
-                                           ID = ID[r1],
-                                           Sex1 = ID[r1],
-                                           Sex2 = ID[r2],
-                                           BirthYear1 = BirthYear[r1],
-                                           BirthYear2 = BirthYear[r2],
-                                           stringsAsFactors = FALSE))
+      r1 <- which(duplicated(LifeHistData$ID, fromLast=TRUE))
+      r2 <- which(duplicated(LifeHistData$ID))
+      LHdup <- merge(LifeHistData[r1,], LifeHistData[r2,], by='ID', suffixes=c('.1', '.2'))
+      col_order <- c(t(outer(c('Sex', 'BirthYear', 'BY.min', 'BY.max', 'Year.last'), 1:2, paste, sep='.')))
+      OUT$DupLifeHistID <- data.frame(ID = LHdup$ID,
+                                      row1 = r1,
+                                      row2 = r2,
+                                      LHdup[, c('ID', intersect(col_order, colnames(LHdup)))],
+                                      stringsAsFactors = FALSE)
     }
     message("duplicate IDs found in lifehistory data, first entry will be used")
     LifeHistData <- LifeHistData[!duplicated(LifeHistData$ID), ]
@@ -143,10 +150,11 @@ CheckLH <- function(LifeHistData, gID = NA, sorted=TRUE, returnDups = FALSE)
 
 
   # check: compliance with hard coded max. age difference of 100 ----
-  # (could be adjusted)
+  # (can be adjusted)
   MaxAgeDif <- with(LifeHistData, suppressWarnings(
     diff(range(BirthYear[BirthYear >= 0 & (ID %in% gID | is.na(gID))], na.rm = TRUE))))
-  if (MaxAgeDif > 100) stop("Cannot handle >100 cohorts!", call.=FALSE)
+  if (MaxAgeDif > 100) stop("Cannot handle age difference of >100 years!",
+                            "\n Please email the package maintainer for a version that does allow longer time spans", call.=FALSE)
 
 
   # return results ----
@@ -192,7 +200,8 @@ orderLH <- function(LH=NULL, gID=NULL) {
                       Sex = 3,
                       BirthYear = -999,
                       BY.min = -999,
-                      BY.max = -999)
+                      BY.max = -999,
+                      Year.last = -999)
   }
   if (is.null(LH)) {
     LHF <- LHX
@@ -203,7 +212,7 @@ orderLH <- function(LH=NULL, gID=NULL) {
     LHF <- LH[match(gID, LH$ID), ]
     # fill in gaps: some gID may not be in LH
     LHF$Sex[is.na(LHF$Sex)] <- 3
-    for (y in c("BirthYear", "BY.min", "BY.max")) {
+    for (y in c("BirthYear", "BY.min", "BY.max", "Year.last")) {
       LHF[is.na(LHF[,y]), y] <- -999
     }
   }
