@@ -8,7 +8,8 @@ integer, intent(IN) :: nind, nsnp
 integer, intent(INOUT) :: genofr(nind*nsnp)
 double precision, intent(IN) :: eprobfr(nsnp*3*3)
 integer :: Genos(nSnp, nInd), l, i, x, j, h
-double precision :: EProb(3,3,nSnp), p(3), r(nSnp, nInd)
+double precision :: EProb(3,3,nSnp), p(3)
+real :: r(nSnp, nInd)
 
 Genos = -9
 j = 0
@@ -39,9 +40,9 @@ do l=1, nSnp
   do i=1,nInd
     if (Genos(l,i)==-9)  cycle
     p = Eprob(Genos(l,i), :, l) / sum(Eprob(Genos(l,i), :, l))
-    if (r(l,i) < p(1)) then
+    if (dble(r(l,i)) < p(1)) then
       x = 0
-    else if (r(l,i) < (p(1) + p(2))) then
+    else if (dble(r(l,i)) < (p(1) + p(2))) then
       x = 1
     else
       x = 2
